@@ -12,10 +12,6 @@ dropNulls <- function(x) {
   x[!vapply(x, is.null, FUN.VALUE = logical(1))]
 }
 
-`%||%` <- function(x, y) {
-  if (!is.null(x)) x else y
-}
-
 formatNoSci <- function(x) {
   if (is.null(x)) return(NULL)
   format(x, scientific = FALSE, digits = 15)
@@ -58,12 +54,10 @@ make_styles <- function(styles) {
 
 #' Utility function to create ApexChart parameters JSON
 #'
-#' @param ax A \code{apexcharts} \code{htmlwidget} object.
+#' @template ax-default
 #' @param name Slot's name to edit
 #' @param ... Arguments for the slot
 #'
-#' @return A \code{apexcharts} \code{htmlwidget} object.
-#'
 #' @importFrom utils modifyList
 #'
 #' @noRd
@@ -84,12 +78,10 @@ make_styles <- function(styles) {
 
 #' Utility function to create ApexChart parameters JSON
 #'
-#' @param ax A \code{apexcharts} \code{htmlwidget} object.
+#' @template ax-default
 #' @param name Slot's name to edit
 #' @param l List of arguments for the slot
 #'
-#' @return A \code{apexcharts} \code{htmlwidget} object.
-#'
 #' @importFrom utils modifyList
 #'
 #' @noRd
